@@ -125,12 +125,13 @@ class EntryRow(Adw.Bin):
     @Gtk.Template.Callback()
     def _on_entry_row_button_pressed(
         self,
-        _gesture: Gtk.GestureClick,
+        gesture: Gtk.GestureClick,
         _n_press: int,
         _event_x: float,
         _event_y: float,
     ) -> None:
         # pylint: disable=too-many-arguments
+        gesture.set_state(Gtk.EventSequenceState.CLAIMED)
         db_view: UnlockedDatabase = self.unlocked_database
         db_view.start_database_lock_timer()
 
@@ -237,6 +238,7 @@ class EntryRow(Adw.Bin):
         self._prefix_stack.props.visible_child = visible_child
 
     @Gtk.Template.Callback()
-    def _on_long_press_gesture_pressed(self, _gesture, _x, _y):
+    def _on_long_press_gesture_pressed(self, gesture, _x, _y):
+        gesture.set_state(Gtk.EventSequenceState.CLAIMED)
         self.unlocked_database.props.selection_mode = True
         self._safe_entry.props.selected = not self._safe_entry.props.selected
