@@ -108,6 +108,9 @@ class SafeElement(GObject.Object):
 
         return False
 
+    def __hash__(self):  # pylint: disable=arguments-differ
+        return hash(self.uuid)
+
     @GObject.Signal(flags=GObject.SignalFlags.ACTION)
     def updated(self):
         """Update the entry.
@@ -344,6 +347,18 @@ class SafeElement(GObject.Object):
         """
         return self._element.uuid
 
+    @GObject.Property(type=str, flags=GObject.ParamFlags.READABLE)
+    def parent_uuid_str(self) -> str:
+        """UUID of the parent group of the element.
+
+        :returns: uuid of the parent
+        :rtype: UUID
+        """
+        if self.is_root_group:
+            return ""
+
+        return str(self.parentgroup_uuid)
+
     @property
     def path(self) -> list[str]:
         return self._element.path
@@ -375,6 +390,25 @@ class SafeElement(GObject.Object):
             time.second,
         )
 
+    @GObject.Property(type=int, flags=GObject.ParamFlags.READABLE)
+    def ctime_int(self) -> int:
+        try:
+            time = self._element.ctime
+        except ValueError:
+            logging.exception("Invalid creation time")
+            return -1
+        except OverflowError:
+            logging.exception("Creation time for %s overflows", self.name)
+            return -1
+        except Exception:  # pylint: disable=broad-except
+            logging.exception("Could not read creation time")
+            return -1
+
+        if not time:
+            return -1
+
+        return time.timestamp()
+
     @property
     def ctime(self) -> GLib.DateTime | None:
         """The UTC creation time of the element."""
@@ -531,14 +565,22 @@ class SafeGroup(SafeElement):
             self._subgroups_filter.changed(Gtk.FilterChange.DIFFERENT)  # type: ignore
 
     def init_subgroups(self):
-        self._subgroups_filter = Gtk.CustomFilter.new(self._group_filter_func)
+        expr = Gtk.PropertyExpression.new(
+            SafeElement.__gtype__, None, "parent_uuid_str"
+        )
+        self._subgroups_filter = Gtk.StringFilter.new(expr)
+        self._subgroups_filter.props.search = str(self.uuid)
         self._subgroups = Gtk.FilterListModel.new(
             self._db_manager.groups,
             self._subgroups_filter,
         )
 
     def init_entries(self):
-        self._entries_filter = Gtk.CustomFilter.new(self._group_filter_func)
+        expr = Gtk.PropertyExpression.new(
+            SafeElement.__gtype__, None, "parent_uuid_str"
+        )
+        self._entries_filter = Gtk.StringFilter.new(expr)
+        self._entries_filter.props.search = str(self.uuid)
         self._entries = Gtk.FilterListModel.new(
             self._db_manager.entries,
             self._entries_filter,
@@ -563,15 +605,6 @@ class SafeGroup(SafeElement):
         """Returns the private pykeepass group."""
         return self._group
 
-    def _entry_filter_func(self, entry: SafeEntry) -> bool:
-        return entry.parentgroup_uuid == self.uuid
-
-    def _group_filter_func(self, group: SafeGroup) -> bool:
-        if group.is_root_group:
-            return False
-
-        return group.parentgroup_uuid == self.uuid
-
     def emit_children_changed(self, removed, added):
         self.emit(self.children_changed, removed, added)
 
